##  Creating Fact Sheets in Jira
You have the option to create new fact sheets on the fly in Jira. When you create a fact sheet from an issue in Jira, it will be synced or linked to the Jira issue accordingly.
To create a fact sheet in Jira, follow these steps:
  1. In the Glance view, choose the SAP LeanIX fact sheet icon.
  2. In the Select box type the name of the new fact sheet and choose Create new Fact Sheet [Name]. Your search term automatically becomes the name for the new fact sheet. If a synchronization mapping is defined for the issue type, the corresponding type is selected as the fact sheet type.
  3. Choose Save. The created fact sheet will appear in the list of synced or linked fact sheets.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274963407a4410148afea4d6704c43ed_LowRes.png)
